@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package App::Spec::Completion::Zsh;
 
-our $VERSION = '0.004_001'; # TRIAL VERSION
+our $VERSION = '0.004_002'; # TRIAL VERSION
 
 use Moo;
 extends 'App::Spec::Completion';
@@ -16,6 +16,7 @@ sub generate_completion {
     my $completion_outer = $self->completion_commands(
         commands => $spec->subcommands,
         options => $spec->options,
+        parameters => $spec->parameters,
         level => 1,
         functions => $functions,
     );
@@ -264,7 +265,7 @@ sub dynamic_completion {
         $function = <<"EOM";
 $function_name() \{
     local __dynamic_completion
-    __dynamic_completion=`PERL5_APPSPECRUN_SHELL=zsh PERL5_APPSPECRUN_COMPLETION_PARAMETER='$name' \$words`
+    __dynamic_completion=`PERL5_APPSPECRUN_SHELL=zsh PERL5_APPSPECRUN_COMPLETION_PARAMETER='$name' "\${words[@]}"`
     __${appname}_dynamic_comp '$name' "\$__dynamic_completion"
 \}
 EOM
