@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package App::Spec::Run;
 use 5.010;
-our $VERSION = '0.004_001'; # TRIAL VERSION
+our $VERSION = '0.004_002'; # TRIAL VERSION
 
 use App::Spec::Run::Validator;
 use App::Spec::Run::Response;
@@ -175,6 +175,12 @@ sub completion_output {
         my $params = $self->parameters;
         my $value = $params->{ $completion_parameter };
         $value = [$value] unless is_arrayref $value;
+        # cmd param1 param2<TAB> results in
+        # @ARGV = ["param1", "param2"]
+        # cmd param1 param2 <TAB> results in
+        # @ARGV = ["param1", "param2", ""]
+        # so we know that there is a new value to be completed
+        my $last = pop @$value;
         @seen{ @$value } = (1) x @$value;
     }
     for my $item (@$result) {
@@ -489,7 +495,14 @@ Does not print the output and does not exit.
 
     $run->out("Hello world!");
 
-Appends to response output. Adds a newline if not present
+Appends to response output. Adds a newline if not present. You can also
+pass a data structure:
+
+    $run->out($hashref);
+
+This will be formatted with L<Data::Dumper>.
+
+See also L<App::Spec::Plugin::Format>.
 
 =item err
 
@@ -656,7 +669,7 @@ Contains a hashref
     {
         print_output => {
             module => $plugin,
-            mathod => 'print_output',
+            method => 'print_output',
         },
     }
 
